@@ -37,7 +37,7 @@
 // Utility 'zip' function analogous to python's, from
 // https://stackoverflow.com/questions/4856717
 
-var Chart = require('chart.js');
+const Chart = require('chart.js');
 const { nodeName } = require('jquery');
 var tinycolor = require('tinycolor2');
 require('chartjs-plugin-zoom');
@@ -342,7 +342,7 @@ BandPlot.prototype.initDosChart = function (orientation = 'vertical') {
                             zeroLineWidth: 2,
                         },
                         ticks: {
-                            min: 0.0,
+                            // min: 0.0,
                         }
                     }],
                     yAxes: [{
@@ -453,7 +453,7 @@ BandPlot.prototype.initDosChart = function (orientation = 'vertical') {
                             tickMarkLength: 0,
                         },
                         ticks: {
-                            min: 0.0,
+                            // min: 0.0,
                             padding: 10,
                         },
                         scaleLabel: {
@@ -782,26 +782,71 @@ BandPlot.prototype.updateDosPlot = function (orientation = 'vertical') {
     var totx = bandPlotObject.dosData['tdos']['energy | eV']['data'];
     var toty = bandPlotObject.dosData['tdos']['values']['dos | states/eV']['data'];
 
-    totx.forEach(function (data, i) {
-        if (orientation === 'vertical') {
-            curve.push({ x: toty[i], y: data - bandPlotObject.dosFermiEnergy });
-        } else {
-            curve.push({ x: data - bandPlotObject.dosFermiEnergy, y: toty[i] });
+    if ('dos_spin_up | states/eV' in bandPlotObject.dosData['tdos']['values']) {
+        var tot_up = bandPlotObject.dosData['tdos']['values']['dos_spin_up | states/eV']['data'];
+        var tot_dn = bandPlotObject.dosData['tdos']['values']['dos_spin_down | states/eV']['data'];
+
+        curve_up = [];
+        curve_dn = [];
+
+        totx.forEach(function (data, i) {
+            if (orientation === 'vertical') {
+                curve_up.push({ x: tot_up[i], y: data - bandPlotObject.dosFermiEnergy });
+                curve_dn.push({ x: -tot_dn[i], y: data - bandPlotObject.dosFermiEnergy });
+            } else {
+                curve_up.push({ x: data - bandPlotObject.dosFermiEnergy, y: tot_up[i] });
+                curve_dn.push({ x: data - bandPlotObject.dosFermiEnergy, y: -tot_dn[i] });
+            };
+        });
+
+        var totdos_up = {
+            borderColor: bandPlotObject.dosColorInfo[0],
+            backgroundColor: bandPlotObject.dosBackgroundColorInfo[0],
+            borderWidth: 2,
+            data: curve_up,
+            fill: true,
+            showLine: true,
+            pointRadius: 0,
+            label: "Total Up",
         };
-    });
 
-    var totdos = {
-        borderColor: bandPlotObject.dosColorInfo[0],
-        backgroundColor: bandPlotObject.dosBackgroundColorInfo[0],
-        borderWidth: 2,
-        data: curve,
-        fill: true,
-        showLine: true,
-        pointRadius: 0,
-        label: "Total",
-    };
+        var totdos_dn = {
+            borderColor: bandPlotObject.dosColorInfo[0],
+            backgroundColor: bandPlotObject.dosBackgroundColorInfo[0],
+            borderWidth: 2,
+            borderDash: [10, 5],
+            data: curve_dn,
+            fill: true,
+            showLine: true,
+            pointRadius: 0,
+            label: "Total Down",
+        };
 
-    bandPlotObject.dosSeries.push(totdos);
+        bandPlotObject.dosSeries.push(totdos_up);
+        bandPlotObject.dosSeries.push(totdos_dn);
+    }
+    else {
+        totx.forEach(function (data, i) {
+            if (orientation === 'vertical') {
+                curve.push({ x: toty[i], y: data - bandPlotObject.dosFermiEnergy });
+            } else {
+                curve.push({ x: data - bandPlotObject.dosFermiEnergy, y: toty[i] });
+            };
+        });
+
+        var totdos = {
+            borderColor: bandPlotObject.dosColorInfo[0],
+            backgroundColor: bandPlotObject.dosBackgroundColorInfo[0],
+            borderWidth: 2,
+            data: curve,
+            fill: true,
+            showLine: true,
+            pointRadius: 0,
+            label: "Total",
+        };
+
+        bandPlotObject.dosSeries.push(totdos);
+    }
 
     for (let i = 1; i < bandPlotObject.dosColorInfo.length; i++) {
         curve = [];
@@ -829,6 +874,10 @@ BandPlot.prototype.updateDosPlot = function (orientation = 'vertical') {
             label: bandPlotObject.dosData['pdos'][i - 1]['kind'] + ' ' + bandPlotObject.dosData['pdos'][i - 1]['orbital'],
         };
 
+        if (bandPlotObject.dosData['pdos'][i - 1]['orbital'].includes('dn')) {
+            pdos.borderDash = [10, 5];
+        };
+
         bandPlotObject.dosSeries.push(pdos);
     };
 
